# Load
library("tm")
library("SnowballC")
library("wordcloud")
library("RColorBrewer")
#load the text
ns_task1 <- readLines(file.choose())

head(ns_task1)
#load the data as corpus
docs_ns_task1 <- Corpus(VectorSource(ns_task1))

#inspect the content of the document
inspect(docs_ns_task1)

#text transforamtion
toSpace <- content_transformer(function (x , pattern ) gsub(pattern, " ", x))
docs_ns_task1 <- tm_map(docs_ns_task1, toSpace, "/")
docs_ns_task1 <- tm_map(docs_ns_task1, toSpace, "@")
docs_ns_task1 <- tm_map(docs_ns_task1, toSpace, "\\|")

#cleaning the text
#convert the text to lower case
docs_ns_task1 <- tm_map(docs_ns_task1, content_transformer(tolower))

#remove numbers
docs_ns_task1 <- tm_map(docs_ns_task1, removeNumbers)

#remove engluish common stopword
docs_ns_task1 <- tm_map(docs_ns_task1, removeWords, stopwords("english"))

#remove punctuation 
docs_ns_task1 <- tm_map(docs_ns_task1, removePunctuation)

#eliminate extra white spaces 
docs_ns_task1 <- tm_map(docs_ns_task1, stripWhitespace)

#text stemming 
docs_ns_task1 <- tm_map(docs_ns_task1, stemDocument)

#build a term_document martix 
dtm_ns_task1 <- TermDocumentMatrix(docs_ns_task1)
m_ns_task1 <- as.matrix(dtm_ns_task1)
v_ns_task1 <- sort(rowSums(m_ns_task1),decreasing=TRUE)
d_ns_task1 <- data.frame(word = names(v_ns_task1),freq=v_ns_task1)
head(d_ns_task1)

#generate the world cloud 
set.seed(1234)
wordcloud(words = d_ns_task1$word, freq = d_ns_task1$freq, min.freq = 1,
          max.words=200, random.order=FALSE, rot.per=0.35, 
          colors=brewer.pal(8, "Dark2"))

#export
install.packages("xlsx")
library(xlsx)
write.xlsx(d_ns_task1,"destop/ns_paper_task1.xlsx")
